<?php
	//引入语言包
	$mn_langpackage=new menulp;
	
	$holder_ID=short_check(get_argg('h'));
	$send_msgscrip='modules.php?app=msg_creator&2id='.$holder_ID.'&nw=2';
	$add_friend="javascript:mypalsAddInit($holder_ID)";
	$leave_word='modules.php?app=msgboard_more&user_id='.$holder_ID;
	$send_hi="hi_action($holder_ID)";
	$send_report="report_action(10,$holder_ID,$holder_ID);";

	if(!isset($user_id)){
	  	$send_msgscrip="javascript:parent.goLogin();";
	  	$add_friend='javascript:parent.goLogin()';
	  	$leave_word="javascript:parent.goLogin();";
	  	$send_hi='javascript:parent.goLogin()';
	  	$send_report='javascript:parent.goLogin()';
	  	set_session('pre_login_url',$_SERVER["REQUEST_URI"]);
	}

	//数据表定义
	$t_data_count=$tablePreStr."data_count";
	$sql="select * from $t_data_count where user_id=$holder_ID";
	$data_num=$dbo->getRow($sql);
	$hi_num=$data_num['hi_num'];
	$blog_num=$data_num['blog_num'];
	$poll_num=$data_num['poll_num'];
	$share_num=$data_num['share_num'];
	$pals_num=$data_num['pals_num'];
	$photo_num=$data_num['photo_num'];
	$group_num=$data_num['group_num'];
	$mood_num=$data_num['mood_num'];
	$msgboard_num=$data_num['msg_num'];
	$scrip_num=$data_num['scrip_num'];
?>